==> miniorange_2fa-8.x-1.211.tar.gz: miniorange_2fa/src/Form/configure_google_authenticator.php <==
<?php
namespace Drupal\miniorange_2fa\form;

use Drupal\user\Entity\User;
use Drupal\Core\Form\FormBase;
use Drupal\miniorange_2fa\MiniorangeUser;
use Drupal\miniorange_2fa\UsersAPIHandler;
use Drupal\miniorange_2fa\MoAuthUtilities;
use Drupal\miniorange_2fa\AuthenticationType;
use Drupal\Component\Render\FormattableMarkup;
use Drupal\miniorange_2fa\AuthenticationAPIHandler;
use Drupal\miniorange_2fa\MiniorangeCustomerProfile;

class configure_google_authenticator extends FormBase
{
    public function getFormId() {
        return 'miniorange_configure_google_authenticator';
    }
    public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state)
    {
        global $base_url;
        $androidAppLink = file_create_url($base_url . '/' . drupal_get_path('module', 'miniorange_2fa') . '/includes/images/android-google-authenticator-app-link.png');
        $iPhoneAppLink = file_create_url($base_url . '/' . drupal_get_path('module', 'miniorange_2fa') . '/includes/images/iphone-google-authenticator-app-link.png');
        $androidAppQR = file_create_url($base_url . '/' . drupal_get_path('module', 'miniorange_2fa') . '/includes/images/android-google-authenticator-app-qr.jpg');
        $iPhoneAppQR = file_create_url($base_url . '/' . drupal_get_path('module', 'miniorange_2fa') . '/includes/images/iphone-google-authenticator-app-qr.jpg');

        $form['markup_library'] = array(
            '#attached' => array(
                'library' => array('miniorange_2fa/miniorange_2fa.admin',
                             "miniorange_2fa/miniorange_2fa.license",),
            ),
        );

        $url = $base_url . '/admin/config/people/miniorange_2fa/setup_twofactor';
        $user = User::load(\Drupal::currentUser()->id());
        $user_id = $user->id();
        $utilities = new MoAuthUtilities();
        $custom_attribute = $utilities::get_users_custom_attribute($user_id);
        $input = $form_state->getUserInput();

        if (array_key_exists('secret', $input) === FALSE) {
            $user_email = $custom_attribute[0]->miniorange_registered_email;
            $customer = new MiniorangeCustomerProfile();
            $miniorange_user = new MiniorangeUser($customer->getCustomerID(), $user_email, NULL, NULL, AuthenticationType::$GOOGLE_AUTHENTICATOR['code']);
            $auth_api_handler = new AuthenticationAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
            $response = $auth_api_handler->getGoogleAuthSecret($miniorange_user);
            $qrCode = isset( $response->qrCodeData ) ? $response->qrCodeData : '';
            $image = new FormattableMarkup('<img src="data:image/jpg;base64, '.$qrCode.'"/>', [':src' => $qrCode]);
            $secret = isset($response->secret) ? $response->secret : '';
        } else {
            $secret = $input['secret'];
            $qrCode = $input['qrCode'];
        }
      $form['markup_top_2'] = array(
        '#markup' => '<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container">'
      );
        $form['header']['#markup'] = '<div class="mo2f-setup-header"><div class="mo2f-setup-header-top-left">Configure Google Authenticator</div></div><br>';// . $this->mo_auth_create_form($base_url, $qrCode, $secret);

        $form['actions_1'] = array(
            '#markup' => '<div>
                    <div class="googleauth-steps"><b>Step 1:</b> Download & Install the Google Authenticator app.</div>
                      <br>                           
                      <div class="maindiv_1"> 
                          <div>
                              <div class="googleauth-download-header">Manual Installation</div>
                              <div class="subDivPosition"><br>
                                <h6>iPhone Users</h6>
                                <ul>
                                  <li>Go to App Store.</li>
                                  <li>Search for Google Authenticator.</li>
                                  <li>Download and install the App.</li>
                                </ul>
                                <a target="_blank" href="https://itunes.apple.com/in/app/google-authenticator/id388497605?mt=8"><img src="' . $iPhoneAppLink . '"></a>
                              </div>
                                                
                              <div><br>
                                <h6>Android Users</h6>
                                <ul>
                                  <li>Go to Google Play Store.</li>
                                  <li>Search for Google Authenticator.</li>
                                  <li>Download and install the App.</li>
                                </ul>
                                <div>
                                   <a target="_blank" href="https://play.google.com/store/apps/details?id=com.google.android.apps.authenticator2"><img src="' . $androidAppLink . '"></a>
                                </div>
                              </div>
                          </div>
                      </div>
                    
                      <div class="maindiv_2">
                        
                          <div class="googleauth-download-header">Scan QR Code</div>
                            
                            <div class="subDivPosition">
                              <div><br>
                                <img src="' . $iPhoneAppQR . '">
                              </div>
                              <span>Apple App Store <b>(iOS)</b></span>
                            </div>
                            
                            <div>
                              <div><br>
                                <img src="' . $androidAppQR . '">
                              </div>
                              <span>Google Play Store <b>(Android)</b></span>
                            </div>
                        
                      </div>
                </div>'
        );

        $secret = MoAuthUtilities::indentSecret($secret);
        $form['actions_2'] = array(
            '#markup' =>'
                    <div class="googleauth-steps"><br><br><b>Step 2:</b> Scan the below QR Code from Google Authenticator app.</div>
                    <br><br>'
        );

        $form['actions_qrcode'] = array(
            '#markup' => isset($image) ? $image : '',
        );

        $form['actions_secret_key'] = array(
            '#markup' =>'<p><b class="CenterOR">OR</b></p>
                         <div class="googleauth-secret">
                            <p>Use the following secret</p>
                            <p id="googleAuthSecret"><b>' . $secret . '</b></p>
                            <p>(Spaces don&#39;t matter)</p>
                          </div>'
        );

        $form['actions_3'] = array(
            '#markup' =>'<div style="width: 100%;float:left;padding-top: 10px;">
                <div class="googleauth-steps"><br><br><b>Step 3:</b> Enter the Passcode generated by Google Authenticator app.</div>
                </div>'
        );

        $form['mo_auth_googleauth_token'] = array(
            '#type' => 'textfield',
            '#maxlength' => 6,
            '#attributes' => array(
                'placeholder' => t('Enter passcode.'),
                'class' => array(
                    'mo2f-textbox',
                    'mo2f-textbox-otp'
                ),
                'style' => 'width:200px',
                //'autofocus' => 'true'
            ),
            '#required' => TRUE,
        );

        $form['secret'] = array(
            '#type' => 'hidden',
            '#value' => $secret
        );
        $form['qrCode'] = array(
            '#type' => 'hidden',
            '#value' => $qrCode
        );
        $form['actions'] = array(
            '#type' => 'actions'
        );
        $form['actions_submit'] = array(
            '#type' => 'submit',
            '#value' => t('Verify and Save'),
        );
        $form['actions_cancel'] = array(
            '#markup' => '<span>&nbsp;&nbsp;</span><a href="'.$url.'"> Cancel</a></div>',

        );
        MoAuthUtilities::AddsupportTab($form,$form_state);



        return $form;
    }

    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

        $form_state->setRebuild();
        $input = $form_state->getUserInput();
        $secret = $input['secret'];

        $user = User::load(\Drupal::currentUser()->id());
        $user_id = $user->id();
        $utilities = new MoAuthUtilities();
        $custom_attribute = $utilities::get_users_custom_attribute($user_id);

        $user_email = $custom_attribute[0]->miniorange_registered_email;
        $otpToken = $input['mo_auth_googleauth_token'];

        $customer = new MiniorangeCustomerProfile();
        $miniorange_user = new MiniorangeUser($customer->getCustomerID(), $user_email, NULL, NULL, AuthenticationType::$GOOGLE_AUTHENTICATOR['code']);
        $auth_api_handler = new AuthenticationAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
        $response = $auth_api_handler->register($miniorange_user, AuthenticationType::$GOOGLE_AUTHENTICATOR['code'], $secret, $otpToken, NULL);

        // Clear all the messages
        \Drupal::messenger()->deleteAll();
        // read API response
        if ($response->status == 'SUCCESS') {
            \Drupal::messenger()->addMessage(t(''), 'status');
            $configured_methods = MoAuthUtilities::mo_auth_get_configured_methods($user_id);

            if (!in_array(AuthenticationType::$GOOGLE_AUTHENTICATOR['code'], $configured_methods)) {
                array_push($configured_methods, AuthenticationType::$GOOGLE_AUTHENTICATOR['code']);
            }
            $config_methods = implode(', ',$configured_methods);
            $user_api_handler = new UsersAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
            $response = $user_api_handler->update($miniorange_user);
            if ($response->status == 'SUCCESS') {
                // Save User
                $user_id = $user->id();
                $utilities = new MoAuthUtilities();
                $available = $utilities::check_for_userID($user_id);
                $database = \Drupal::database();

                if($available == TRUE) {
                    $database->update('UserAuthenticationType')->fields(['activated_auth_methods'=> AuthenticationType::$GOOGLE_AUTHENTICATOR['code']])->condition('uid', $user_id,'=')->execute();
                    $database->update('UserAuthenticationType')->fields(['configured_auth_methods'=> $config_methods])->condition('uid', $user_id,'=')->execute();
                }else {
                    echo "error while updating authentication method.";exit;
                }

                $message = 'Google Authenticator configured successfully.';
                MoAuthUtilities::show_error_or_success_message($message , 'status');
            }
        } elseif ($response->status == 'FAILED') {
           \Drupal::messenger()->addMessage(t('The passcode you have entered is incorrect. Please try again.'), 'error');
        } else {

            $message = 'An error occured while processing your request. Please try again.';
            MoAuthUtilities::show_error_or_success_message($message , 'error');
        }
    }
}

==> miniorange_2fa-8.x-2.0.tar.gz: miniorange_2fa/src/Form/configure_google_authenticator.php <==
<?php
namespace Drupal\miniorange_2fa\form;

use Drupal\user\Entity\User;
use Drupal\Core\Form\FormBase;
use Drupal\miniorange_2fa\MiniorangeUser;
use Drupal\miniorange_2fa\UsersAPIHandler;
use Drupal\miniorange_2fa\MoAuthUtilities;
use Drupal\miniorange_2fa\AuthenticationType;
use Drupal\Component\Render\FormattableMarkup;
use Drupal\miniorange_2fa\AuthenticationAPIHandler;
use Drupal\miniorange_2fa\MiniorangeCustomerProfile;

class configure_google_authenticator extends FormBase
{
    public function getFormId() {
        return 'miniorange_configure_google_authenticator';
    }
    public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state)
    {
        global $base_url;
        $androidAppLink = file_create_url($base_url . '/' . drupal_get_path('module', 'miniorange_2fa') . '/includes/images/android-google-authenticator-app-link.png');
        $iPhoneAppLink = file_create_url($base_url . '/' . drupal_get_path('module', 'miniorange_2fa') . '/includes/images/iphone-google-authenticator-app-link.png');
        $androidAppQR = file_create_url($base_url . '/' . drupal_get_path('module', 'miniorange_2fa') . '/includes/images/android-google-authenticator-app-qr.jpg');
        $iPhoneAppQR = file_create_url($base_url . '/' . drupal_get_path('module', 'miniorange_2fa') . '/includes/images/iphone-google-authenticator-app-qr.jpg');

        $form['markup_library'] = array(
            '#attached' => array(
                'library' => array('miniorange_2fa/miniorange_2fa.admin',
                             "miniorange_2fa/miniorange_2fa.license",),
            ),
        );

        $url = $base_url . '/admin/config/people/miniorange_2fa/setup_twofactor';
        $user = User::load(\Drupal::currentUser()->id());
        $user_id = $user->id();
        $utilities = new MoAuthUtilities();
        $custom_attribute = $utilities::get_users_custom_attribute($user_id);
        $input = $form_state->getUserInput();

        if (array_key_exists('secret', $input) === FALSE) {
            $user_email = $custom_attribute[0]->miniorange_registered_email;
            $customer = new MiniorangeCustomerProfile();
            $miniorange_user = new MiniorangeUser($customer->getCustomerID(), $user_email, NULL, NULL, AuthenticationType::$GOOGLE_AUTHENTICATOR['code']);
            $auth_api_handler = new AuthenticationAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
            $response = $auth_api_handler->getGoogleAuthSecret($miniorange_user);
            $qrCode = isset( $response->qrCodeData ) ? $response->qrCodeData : '';
            $image = new FormattableMarkup('<img src="data:image/jpg;base64, '.$qrCode.'"/>', [':src' => $qrCode]);
            $secret = isset($response->secret) ? $response->secret : '';
        } else {
            $secret = $input['secret'];
            $qrCode = $input['qrCode'];
        }
      $form['markup_top_2'] = array(
        '#markup' => '<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container">'
      );
        $form['header']['#markup'] = t('<div class="mo2f-setup-header"><div class="mo2f-setup-header-top-left">Configure Google Authenticator</div></div><br>');

        $form['actions_1'] = array(
            '#markup' => t('<div>
                    <div class="googleauth-steps"><b>Step 1:</b> Download & Install the Google Authenticator app.</div>
                      <br>                           
                      <div class="maindiv_1"> 
                          <div>
                              <div class="googleauth-download-header">Manual Installation</div>
                              <div class="subDivPosition"><br>
                                <h6>iPhone Users</h6>
                                <ul>
                                  <li>Go to App Store.</li>
                                  <li>Search for Google Authenticator.</li>
                                  <li>Download and install the App.</li>
                                </ul>
                                <a target="_blank" href="https://itunes.apple.com/in/app/google-authenticator/id388497605?mt=8"><img src="' . $iPhoneAppLink . '"></a>
                              </div>
                                                
                              <div><br>
                                <h6>Android Users</h6>
                                <ul>
                                  <li>Go to Google Play Store.</li>
                                  <li>Search for Google Authenticator.</li>
                                  <li>Download and install the App.</li>
                                </ul>
                                <div>
                                   <a target="_blank" href="https://play.google.com/store/apps/details?id=com.google.android.apps.authenticator2"><img src="' . $androidAppLink . '"></a>
                                </div>
                              </div>
                          </div>
                      </div>
                    
                      <div class="maindiv_2">
                        
                          <div class="googleauth-download-header">Scan QR Code</div>
                            
                            <div class="subDivPosition">
                              <div><br>
                                <img src="' . $iPhoneAppQR . '">
                              </div>
                              <span>Apple App Store <b>(iOS)</b></span>
                            </div>
                            
                            <div>
                              <div><br>
                                <img src="' . $androidAppQR . '">
                              </div>
                              <span>Google Play Store <b>(Android)</b></span>
                            </div>
                        
                      </div>
                </div>')
        );

        $secret = MoAuthUtilities::indentSecret($secret);
        $form['actions_2'] = array(
            '#markup' =>t('
                    <div class="googleauth-steps"><br><br><b>Step 2:</b> Scan the below QR Code from Google Authenticator app.</div>
                    <br><br>')
        );

        $form['actions_qrcode'] = array(
            '#markup' => isset($image) ? $image : '',
        );

        $form['actions_secret_key'] = array(
            '#markup' =>t('<p><b class="CenterOR">OR</b></p>
                         <div class="googleauth-secret">
                            <p>Use the following secret</p>
                            <p id="googleAuthSecret"><b>' . $secret . '</b></p>
                            <p>(Spaces don&#39;t matter)</p>
                          </div>')
        );

        $form['actions_3'] = array(
            '#markup' => t('<div style="width: 100%;float:left;padding-top: 10px;">
                <div class="googleauth-steps"><br><br><b>Step 3:</b> Enter the Passcode generated by Google Authenticator app.</div>
                </div>')
        );

        $form['mo_auth_googleauth_token'] = array(
            '#type' => 'textfield',
            '#maxlength' => 6,
            '#attributes' => array(
                'placeholder' => t('Enter passcode.'),
                'class' => array(
                    'mo2f-textbox',
                    'mo2f-textbox-otp'
                ),
                'style' => 'width:200px',
                //'autofocus' => 'true'
            ),
            '#required' => TRUE,
        );

        $form['secret'] = array(
            '#type' => 'hidden',
            '#value' => $secret
        );
        $form['qrCode'] = array(
            '#type' => 'hidden',
            '#value' => $qrCode
        );
        $form['actions'] = array(
            '#type' => 'actions'
        );
        $form['actions_submit'] = array(
            '#type' => 'submit',
            '#value' => t('Verify and Save'),
        );
        $form['actions_cancel'] = array(
            '#markup' => '<span>&nbsp;&nbsp;</span><a href="'.$url.'"> Cancel</a></div>',

        );
        MoAuthUtilities::AddsupportTab($form,$form_state);



        return $form;
    }

    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

        $form_state->setRebuild();
        $input = $form_state->getUserInput();
        $secret = $input['secret'];

        $user = User::load(\Drupal::currentUser()->id());
        $user_id = $user->id();
        $utilities = new MoAuthUtilities();
        $custom_attribute = $utilities::get_users_custom_attribute($user_id);

        $user_email = $custom_attribute[0]->miniorange_registered_email;
        $otpToken = $input['mo_auth_googleauth_token'];

        $customer = new MiniorangeCustomerProfile();
        $miniorange_user = new MiniorangeUser($customer->getCustomerID(), $user_email, NULL, NULL, AuthenticationType::$GOOGLE_AUTHENTICATOR['code']);
        $auth_api_handler = new AuthenticationAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
        $response = $auth_api_handler->register($miniorange_user, AuthenticationType::$GOOGLE_AUTHENTICATOR['code'], $secret, $otpToken, NULL);

        // Clear all the messages
        \Drupal::messenger()->deleteAll();
        // read API response
        if ($response->status == 'SUCCESS') {
            \Drupal::messenger()->addMessage(t(''), 'status');
            $configured_methods = MoAuthUtilities::mo_auth_get_configured_methods($user_id);

            if (!in_array(AuthenticationType::$GOOGLE_AUTHENTICATOR['code'], $configured_methods)) {
                array_push($configured_methods, AuthenticationType::$GOOGLE_AUTHENTICATOR['code']);
            }
            $config_methods = implode(', ',$configured_methods);
            $user_api_handler = new UsersAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
            $response = $user_api_handler->update($miniorange_user);
            if ($response->status == 'SUCCESS') {
                // Save User
                $user_id = $user->id();
                $utilities = new MoAuthUtilities();
                $available = $utilities::check_for_userID($user_id);
                $database = \Drupal::database();

                if($available == TRUE) {
                    $database->update('UserAuthenticationType')->fields(['activated_auth_methods'=> AuthenticationType::$GOOGLE_AUTHENTICATOR['code']])->condition('uid', $user_id,'=')->execute();
                    $database->update('UserAuthenticationType')->fields(['configured_auth_methods'=> $config_methods])->condition('uid', $user_id,'=')->execute();
                }else {
                    echo "error while updating authentication method.";exit;
                }

                $message = t('Google Authenticator configured successfully.');
                MoAuthUtilities::show_error_or_success_message($message , 'status');
            }
        } elseif ($response->status == 'FAILED') {
           \Drupal::messenger()->addMessage(t('The passcode you have entered is incorrect. Please try again.'), 'error');
        } else {

            $message = t('An error occured while processing your request. Please try again.');
            MoAuthUtilities::show_error_or_success_message($message , 'error');
        }
    }
}
